Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/memory/hipExtMallocWithFlags.cc
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

118 lines
3.8 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
#include <hip_test_common.hh>
#include <hip/hip_runtime_api.h>
#include <utils.hh>
HIP_TEST_CASE(Unit_hipExtMallocWithFlags_Positive_Basic) {
void* ptr = nullptr;
SECTION("hipDeviceMallocDefault") {
const auto alloc_size =
GENERATE_COPY(10, kPageSize / 2, kPageSize, kPageSize * 3 / 2, kPageSize * 2);
HIP_CHECK(hipExtMallocWithFlags(&ptr, alloc_size, hipDeviceMallocDefault));
CHECK(ptr != nullptr);
CHECK(reinterpret_cast<intptr_t>(ptr) % 256 == 0);
HIP_CHECK(hipFree(ptr));
}
SECTION("hipDeviceMallocFinegrained") {
if (!DeviceAttributesSupport(0, hipDeviceAttributeFineGrainSupport)) {
WARN("Skipping section: " << HipTest::SkipReason::kFineGrainHwUnsupported);
return;
}
const auto alloc_size =
GENERATE_COPY(10, kPageSize / 2, kPageSize, kPageSize * 3 / 2, kPageSize * 2);
HIP_CHECK(hipExtMallocWithFlags(&ptr, alloc_size, hipDeviceMallocFinegrained));
CHECK(ptr != nullptr);
CHECK(reinterpret_cast<intptr_t>(ptr) % 256 == 0);
HIP_CHECK(hipFree(ptr));
}
SECTION("hipMallocSignalMemory") {
HIP_CHECK(hipExtMallocWithFlags(&ptr, 8, hipMallocSignalMemory));
CHECK(ptr != nullptr);
HIP_CHECK(hipFree(ptr));
}
}
HIP_TEST_CASE(Unit_hipExtMallocWithFlags_Positive_Zero_Size) {
void* ptr = reinterpret_cast<void*>(0x1);
const auto flag = GENERATE(hipDeviceMallocDefault, hipDeviceMallocFinegrained);
HIP_CHECK(hipExtMallocWithFlags(&ptr, 0, flag));
REQUIRE(ptr == nullptr);
}
HIP_TEST_CASE(Unit_hipExtMallocWithFlags_Positive_Alignment) {
void *ptr1 = nullptr, *ptr2 = nullptr;
const auto flag = GENERATE(hipDeviceMallocDefault, hipDeviceMallocFinegrained);
if (flag == hipDeviceMallocFinegrained &&
!DeviceAttributesSupport(0, hipDeviceAttributeFineGrainSupport)) {
HIP_SKIP_TEST(HipTest::SkipReason::kFineGrainHwUnsupported);
}
HIP_CHECK(hipExtMallocWithFlags(&ptr1, 1, flag));
HIP_CHECK(hipExtMallocWithFlags(&ptr2, 10, flag));
CHECK(reinterpret_cast<intptr_t>(ptr1) % 256 == 0);
CHECK(reinterpret_cast<intptr_t>(ptr2) % 256 == 0);
HIP_CHECK(hipFree(ptr1));
HIP_CHECK(hipFree(ptr2));
}
HIP_TEST_CASE(Unit_hipExtMallocWithFlags_Negative_Parameters) {
SECTION("Invalid flags") {
void* ptr = nullptr;
HIP_CHECK_ERROR(
hipExtMallocWithFlags(&ptr, 4096, hipDeviceMallocDefault | hipMallocSignalMemory),
hipErrorInvalidValue);
}
SECTION("hipDeviceMallocDefault") {
SECTION("ptr == nullptr") {
HIP_CHECK_ERROR(hipExtMallocWithFlags(nullptr, 4096, hipDeviceMallocDefault),
hipErrorInvalidValue);
}
SECTION("size == max size_t") {
void* ptr;
HIP_CHECK_ERROR(
hipExtMallocWithFlags(&ptr, std::numeric_limits<size_t>::max(), hipDeviceMallocDefault),
hipErrorOutOfMemory);
}
}
SECTION("hipDeviceMallocFinegrained") {
SECTION("ptr == nullptr") {
HIP_CHECK_ERROR(hipExtMallocWithFlags(nullptr, 4096, hipDeviceMallocFinegrained),
hipErrorInvalidValue);
}
SECTION("size == max size_t") {
void* ptr;
HIP_CHECK_ERROR(hipExtMallocWithFlags(&ptr, std::numeric_limits<size_t>::max(),
hipDeviceMallocFinegrained),
hipErrorOutOfMemory);
}
}
SECTION("hipMallocSignalMemory") {
SECTION("ptr == nullptr") {
HIP_CHECK_ERROR(hipExtMallocWithFlags(nullptr, 4096, hipMallocSignalMemory),
hipErrorInvalidValue);
}
SECTION("size == 0") {
void* ptr;
HIP_CHECK_ERROR(hipExtMallocWithFlags(&ptr, 0, hipMallocSignalMemory), hipErrorInvalidValue);
}
SECTION("size != 8") {
void* ptr;
HIP_CHECK_ERROR(hipExtMallocWithFlags(&ptr, 16, hipMallocSignalMemory), hipErrorInvalidValue);
}
}
}